indicatortools.Tuning
=====================

.. abjad-lineage:: abjad.tools.indicatortools.Tuning.Tuning

.. autoclass:: abjad.tools.indicatortools.Tuning.Tuning

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.indicatortools.Tuning.Tuning.get_pitch_ranges_by_string_number
      ~abjad.tools.indicatortools.Tuning.Tuning.get_pitches_by_string_number
      ~abjad.tools.indicatortools.Tuning.Tuning.pitch_ranges
      ~abjad.tools.indicatortools.Tuning.Tuning.pitches
      ~abjad.tools.indicatortools.Tuning.Tuning.voice_pitch_classes
      ~abjad.tools.indicatortools.Tuning.Tuning.__eq__
      ~abjad.tools.indicatortools.Tuning.Tuning.__format__
      ~abjad.tools.indicatortools.Tuning.Tuning.__hash__
      ~abjad.tools.indicatortools.Tuning.Tuning.__ne__
      ~abjad.tools.indicatortools.Tuning.Tuning.__repr__

Bases
-----

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject>`

- :py:class:`abctools.AbjadObject.AbstractBase <abjad.tools.abctools.AbjadObject.AbstractBase>`

- :py:class:`__builtin__.object <object>`

Read-only properties
--------------------

.. autoattribute:: abjad.tools.indicatortools.Tuning.Tuning.pitch_ranges
   :noindex:

.. autoattribute:: abjad.tools.indicatortools.Tuning.Tuning.pitches
   :noindex:

Methods
-------

.. automethod:: abjad.tools.indicatortools.Tuning.Tuning.get_pitch_ranges_by_string_number
   :noindex:

.. automethod:: abjad.tools.indicatortools.Tuning.Tuning.get_pitches_by_string_number
   :noindex:

.. automethod:: abjad.tools.indicatortools.Tuning.Tuning.voice_pitch_classes
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.indicatortools.Tuning.Tuning.__eq__
   :noindex:

.. automethod:: abjad.tools.indicatortools.Tuning.Tuning.__format__
   :noindex:

.. automethod:: abjad.tools.indicatortools.Tuning.Tuning.__hash__
   :noindex:

.. automethod:: abjad.tools.indicatortools.Tuning.Tuning.__ne__
   :noindex:

.. automethod:: abjad.tools.indicatortools.Tuning.Tuning.__repr__
   :noindex:
